@@ -4,7 +4,6 @@ extern crate proc_macro;
 
 mod derive;
 mod node;
-mod owned;
 mod symbols;
 mod visit;
 
@@ -22,11 +21,6 @@ pub fn derive_node(input: TokenStream) -> TokenStream {
     node::NodeGenerator::derive(input)
 }
 
-#[proc_macro_derive(Owned)]
-pub fn derive_owned(input: TokenStream) -> TokenStream {
-    owned::OwnedGenerator::derive(input)
-}
-
 #[proc_macro]
 pub fn symbols(input: TokenStream) -> TokenStream {
     symbols::parse(input)
